@@ -103,7 +103,7 @@ bool validateFileName(const QString &name, bool allowDirectories)
     // Substrings
     const int notAllowedSubStringCount = sizeof(notAllowedSubStrings) / sizeof(const char *);
     for (int s = 0; s < notAllowedSubStringCount; s++) {
-        const QLatin1String notAllowedSubString(notAllowedSubStrings[s]);
+        const QLatin1StringView notAllowedSubString(notAllowedSubStrings[s]);
         if (name.contains(notAllowedSubString)) {
             return false;
         }
@@ -296,7 +296,7 @@ QString AttachmentModel::saveAttachmentToPath(const MimeTreeParser::MessagePart:
     }
 
     QFile f(path);
-    if (!f.open(QIODevice::ReadWrite)) {
+    if (!f.open(QIODevice::WriteOnly)) {
         qCWarning(MIMETREEPARSER_CORE_LOG) << "Failed to write attachment to file:" << path << " Error: " << f.errorString();
         Q_EMIT errorOccurred(i18ndc("mimetreeparser", "@info", "Failed to save attachment."));
         return {};
@@ -378,13 +378,17 @@ bool AttachmentModel::importPublicKey(const MimeTreeParser::MessagePart::Ptr &pa
 
     connect(importJob, &QGpgME::AbstractImportJob::result, this, [this](const GpgME::ImportResult &result) {
         if (result.numConsidered() == 0) {
-            Q_EMIT errorOccurred(i18ndc("mimetreeparser", "@info", "No keys were found in this attachment"));
+            Q_EMIT errorOccurred(i18ndc("mimetreeparser", "@info", "No certificates were found in this attachment"));
             return;
         } else {
-            QString message = i18ndcp("mimetreeparser", "@info", "one key imported", "%1 keys imported", result.numImported());
+            QString message = i18ndcp("mimetreeparser", "@info", "one certificate imported", "%1 certificates imported", result.numImported());
             if (result.numUnchanged() != 0) {
                 message += QStringLiteral("\n")
-                    + i18ndcp("mimetreeparser", "@info", "one key was already imported", "%1 keys were already imported", result.numUnchanged());
+                    + i18ndcp("mimetreeparser",
+                              "@info",
+                              "one certificate was already imported",
+                              "%1 certificates were already imported",
+                              result.numUnchanged());
             }
             Q_EMIT info(message);
         }
