@@ -96,13 +96,13 @@ static KMime::Headers::ContentType *contentType(KMime::Content *node)
 QByteArray MessagePart::charset() const
 {
     if (!mNode) {
-        return "us-ascii";
+        return QByteArrayLiteral("us-ascii");
     }
     if (auto ct = contentType(mNode)) {
         return ct->charset();
     }
     // Per rfc2045 us-ascii is the default
-    return "us-ascii";
+    return QByteArrayLiteral("us-ascii");
 }
 
 QByteArray MessagePart::mimeType() const
@@ -220,7 +220,7 @@ void MessagePart::parseInternal(const QByteArray &data)
     bindLifetime(tempNode);
 
     if (!tempNode->head().isEmpty()) {
-        tempNode->contentDescription()->from7BitString("temporary node");
+        tempNode->contentDescription()->from7BitString(QByteArrayLiteral("temporary node"));
     }
 
     parseInternal(tempNode);
@@ -769,7 +769,7 @@ void SignedMessagePart::sigStatusToMetaData()
                 if (partMetaData()->signer.isEmpty()) {
                     partMetaData()->signer = partMetaData()->signerMailAddresses.front();
                 } else {
-                    partMetaData()->signer += QLatin1String(" <") + partMetaData()->signerMailAddresses.front() + QLatin1Char('>');
+                    partMetaData()->signer += QLatin1StringView(" <") + partMetaData()->signerMailAddresses.front() + QLatin1Char('>');
                 }
             }
         }
@@ -989,7 +989,7 @@ bool EncryptedMessagePart::decrypt(KMime::Content &data)
         } else if (cannotDecrypt) {
             partMetaData()->errorText = i18n("Crypto plug-in \"%1\" cannot decrypt messages.", cryptPlugLibName);
         } else if (!passphraseError()) {
-            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" could not decrypt the data.", cryptPlugLibName) + QLatin1String("<br />")
+            partMetaData()->errorText = i18n("Crypto plug-in \"%1\" could not decrypt the data.", cryptPlugLibName) + QLatin1StringView("<br />")
                 + i18n("Error: %1", partMetaData()->errorText);
         }
     }
